@@ -20,15 +20,15 @@ pub enum Action {
     ScrollToTop,
     ScrollToBottom,
     React,
-    SendReaction((EventId, XOnlyPublicKey)),
+    SendReaction(Event),
     Repost,
-    SendRepost((EventId, XOnlyPublicKey)),
+    SendRepost(Event),
     Unselect,
     NewTextNote,
     ReplyTextNote,
     SubmitTextNote,
     SendTextNote(String, Vec<Tag>),
     Key(KeyEvent),
-    MetadataUpdated(Metadata),
+    MetadataUpdated(Box<Metadata>),
     SystemMessage(String),
 }
