@@ -1,7 +1,6 @@
 mod connection;
 mod connection_process;
 mod event;
-mod metadata;
 pub mod nip10;
 pub mod nip27;
 mod profile;
@@ -9,5 +8,4 @@ mod profile;
 pub use connection::Connection;
 pub use connection_process::ConnectionProcess;
 pub use event::SortableEvent;
-pub use metadata::Metadata;
 pub use profile::Profile;
